@@ -76,8 +76,7 @@ int cw_general_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 0, 1,
 			                  0, GTK_EXPAND | GTK_FILL, 0, 0 );
 
-			wav_file_name_format_entry
-			= gtk_entry_new_with_max_length( MAX_FILE_NAME_LENGTH - 3 );
+			wav_file_name_format_entry = gtk_entry_new_with_max_length( MAX_FILE_NAME_LENGTH - 3 );
 			gtk_entry_set_text( GTK_ENTRY( wav_file_name_format_entry ),
 			                    config.wav_file_name_format );
 			gtk_table_attach( GTK_TABLE( table ),
@@ -772,7 +771,7 @@ int cw_files_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 {
 	static GtkWidget * main_frame;
 	static GtkWidget *format_string_entry, *dir_format_string_entry;
-	static GtkWidget *convert_spaces_ckbx, *make_directories_ckbx, *create_id3_ckbx;
+	static GtkWidget *convert_spaces_ckbx, *make_directories_ckbx, *create_id3_ckbx, *create_playlist_ckbx;
 	static GtkWidget *table, *vbox, *hbox;
 
 	switch ( ops ) {
@@ -803,6 +802,12 @@ int cw_files_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( create_id3_ckbx ),
 			                             config.cddb_config.create_id3 );
 			gtk_container_add( GTK_CONTAINER( vbox ), create_id3_ckbx );
+			
+			/* Create m3u playlist file */
+			create_playlist_ckbx = gtk_check_button_new_with_label( "Create m3u playlist" );
+			gtk_toggle_button_set_state( GTK_TOGGLE_BUTTON( create_playlist_ckbx ),
+			                             config.cddb_config.create_playlist );
+			gtk_container_add( GTK_CONTAINER( vbox ), create_playlist_ckbx );
 
 			/* format string entry */
 			hbox = gtk_hbox_new( FALSE, 0 );
@@ -872,6 +877,11 @@ int cw_files_handler( int ops, _main_data *main_data, GtkWidget *notebook )
 			config.cddb_config.create_id3 = 1;
 		else
 			config.cddb_config.create_id3 = 0;
+		
+		if ( GTK_TOGGLE_BUTTON( create_playlist_ckbx ) ->active )
+			config.cddb_config.create_playlist = 1;
+		else
+			config.cddb_config.create_playlist = 0;
 
 		strcpy( config.cddb_config.format_string,
 		        gtk_entry_get_text( GTK_ENTRY( format_string_entry ) ) );
