@@ -13,6 +13,9 @@
 #define SF_SYNC_MAIN_DATA			106
 #define SF_SYNC_SELECT_FRAME		107
 
+#define SF_YEAR_ENTRY_CHG			110
+#define SF_GENRE_ENTRY_CHG			111
+
 /* Create or destroy select frame. ops can be one of WIDGET_CREATE,
  * WIDGET_DESTROY, SF_WAV_BUTTON_ACT, SF_MP3_BUTTON_ACT, 
  * , SF_WAV_ENTRY_CHG, SF_MP3_ENTRY_CHG, and SF_SYNC_MAIN_DATA.
